==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/PortSelectorFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class PortSelectorFluentImpl<A extends me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<A>{

    private VisitableBuilder<? extends me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port,?> port;

    public PortSelectorFluentImpl(){
    }
    public PortSelectorFluentImpl(me.snowdrop.istio.api.networking.v1alpha3.PortSelector instance){
            this.withPort(instance.getPort()); 
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port getPort(){
            return this.port!=null?this.port.build():null;
    }

    public me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port buildPort(){
            return this.port!=null?this.port.build():null;
    }

    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port port){
            if (port instanceof me.snowdrop.istio.api.networking.v1alpha3.NumberPort){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder((me.snowdrop.istio.api.networking.v1alpha3.NumberPort)port); _visitables.add(this.port);}
            if (port instanceof me.snowdrop.istio.api.networking.v1alpha3.NamePort){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder((me.snowdrop.istio.api.networking.v1alpha3.NamePort)port); _visitables.add(this.port);}
            return (A) this;
    }

    public Boolean hasPort(){
            return this.port != null;
    }

    public A withNumberPort(me.snowdrop.istio.api.networking.v1alpha3.NumberPort numberPort){
            _visitables.remove(this.port);
            if (numberPort!=null){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(numberPort); _visitables.add(this.port);} return (A) this;
    }

    public PortSelectorFluent.NumberPortNested<A> withNewNumberPort(){
            return new NumberPortNestedImpl();
    }

    public PortSelectorFluent.NumberPortNested<A> withNewNumberPortLike(me.snowdrop.istio.api.networking.v1alpha3.NumberPort item){
            return new NumberPortNestedImpl(item);
    }

    public A withNewNumberPort(Integer number){
            return (A)withNumberPort(new NumberPort(number));
    }

    public A withNamePort(me.snowdrop.istio.api.networking.v1alpha3.NamePort namePort){
            _visitables.remove(this.port);
            if (namePort!=null){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(namePort); _visitables.add(this.port);} return (A) this;
    }

    public PortSelectorFluent.NamePortNested<A> withNewNamePort(){
            return new NamePortNestedImpl();
    }

    public PortSelectorFluent.NamePortNested<A> withNewNamePortLike(me.snowdrop.istio.api.networking.v1alpha3.NamePort item){
            return new NamePortNestedImpl(item);
    }

    public A withNewNamePort(String name){
            return (A)withNamePort(new NamePort(name));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PortSelectorFluentImpl that = (PortSelectorFluentImpl) o;
            if (port != null ? !port.equals(that.port) :that.port != null) return false;
            return true;
    }


    public class NumberPortNestedImpl<N> extends me.snowdrop.istio.api.networking.v1alpha3.NumberPortFluentImpl<PortSelectorFluent.NumberPortNested<N>> implements PortSelectorFluent.NumberPortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder builder;
    
            NumberPortNestedImpl(me.snowdrop.istio.api.networking.v1alpha3.NumberPort item){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(this, item);
            }
            NumberPortNestedImpl(){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(this);
            }
    
    public N and(){
            return (N) PortSelectorFluentImpl.this.withNumberPort(builder.build());
    }
    public N endNumberPort(){
            return and();
    }

}
    public class NamePortNestedImpl<N> extends me.snowdrop.istio.api.networking.v1alpha3.NamePortFluentImpl<PortSelectorFluent.NamePortNested<N>> implements PortSelectorFluent.NamePortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder builder;
    
            NamePortNestedImpl(me.snowdrop.istio.api.networking.v1alpha3.NamePort item){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(this, item);
            }
            NamePortNestedImpl(){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(this);
            }
    
    public N and(){
            return (N) PortSelectorFluentImpl.this.withNamePort(builder.build());
    }
    public N endNamePort(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/PortSelectorFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class PortSelectorFluentImpl<A extends me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<A>{

    private VisitableBuilder<? extends me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port,?> port;

    public PortSelectorFluentImpl(){
    }
    public PortSelectorFluentImpl(me.snowdrop.istio.api.networking.v1alpha3.PortSelector instance){
            this.withPort(instance.getPort()); 
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port getPort(){
            return this.port!=null?this.port.build():null;
    }

    public me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port buildPort(){
            return this.port!=null?this.port.build():null;
    }

    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.PortSelector.Port port){
            if (port instanceof me.snowdrop.istio.api.networking.v1alpha3.NumberPort){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder((me.snowdrop.istio.api.networking.v1alpha3.NumberPort)port); _visitables.get("port").add(this.port);}
            if (port instanceof me.snowdrop.istio.api.networking.v1alpha3.NamePort){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder((me.snowdrop.istio.api.networking.v1alpha3.NamePort)port); _visitables.get("port").add(this.port);}
            return (A) this;
    }

    public Boolean hasPort(){
            return this.port != null;
    }

    public A withNumberPort(me.snowdrop.istio.api.networking.v1alpha3.NumberPort numberPort){
            _visitables.get("port").remove(this.port);
            if (numberPort!=null){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(numberPort); _visitables.get("port").add(this.port);} return (A) this;
    }

    public PortSelectorFluent.NumberPortNested<A> withNewNumberPort(){
            return new NumberPortNestedImpl();
    }

    public PortSelectorFluent.NumberPortNested<A> withNewNumberPortLike(me.snowdrop.istio.api.networking.v1alpha3.NumberPort item){
            return new NumberPortNestedImpl(item);
    }

    public A withNewNumberPort(Integer number){
            return (A)withNumberPort(new NumberPort(number));
    }

    public A withNamePort(me.snowdrop.istio.api.networking.v1alpha3.NamePort namePort){
            _visitables.get("port").remove(this.port);
            if (namePort!=null){ this.port= new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(namePort); _visitables.get("port").add(this.port);} return (A) this;
    }

    public PortSelectorFluent.NamePortNested<A> withNewNamePort(){
            return new NamePortNestedImpl();
    }

    public PortSelectorFluent.NamePortNested<A> withNewNamePortLike(me.snowdrop.istio.api.networking.v1alpha3.NamePort item){
            return new NamePortNestedImpl(item);
    }

    public A withNewNamePort(String name){
            return (A)withNamePort(new NamePort(name));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            PortSelectorFluentImpl that = (PortSelectorFluentImpl) o;
            if (port != null ? !port.equals(that.port) :that.port != null) return false;
            return true;
    }


    public class NumberPortNestedImpl<N> extends me.snowdrop.istio.api.networking.v1alpha3.NumberPortFluentImpl<PortSelectorFluent.NumberPortNested<N>> implements PortSelectorFluent.NumberPortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder builder;
    
            NumberPortNestedImpl(me.snowdrop.istio.api.networking.v1alpha3.NumberPort item){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(this, item);
            }
            NumberPortNestedImpl(){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NumberPortBuilder(this);
            }
    
    public N and(){
            return (N) PortSelectorFluentImpl.this.withNumberPort(builder.build());
    }
    public N endNumberPort(){
            return and();
    }

}
    public class NamePortNestedImpl<N> extends me.snowdrop.istio.api.networking.v1alpha3.NamePortFluentImpl<PortSelectorFluent.NamePortNested<N>> implements PortSelectorFluent.NamePortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder builder;
    
            NamePortNestedImpl(me.snowdrop.istio.api.networking.v1alpha3.NamePort item){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(this, item);
            }
            NamePortNestedImpl(){
                    this.builder = new me.snowdrop.istio.api.networking.v1alpha3.NamePortBuilder(this);
            }
    
    public N and(){
            return (N) PortSelectorFluentImpl.this.withNamePort(builder.build());
    }
    public N endNamePort(){
            return and();
    }

}


}
